@@ -5,9 +5,9 @@ from .const import *
 from .context import connected
 from .context import handle_exit
 from .core import *
-from .helpers import as_dict_all
+from .helpers import dictify
 from .oem import *
-
+as_dict_all = dictify #alias
 __version__ = _mt5.__version__
 __author__ = _mt5.__author__
 
